#!/usr/bin/ruby
# Copyright (c) 2012, Comfirm AB
# All rights reserved.

# Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:

#     * Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
#     * Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
#     * Neither the name of the Comfirm AB nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.

# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

require 'rubygems'
require 'alphamail'

# In this demo we are going to send name and password to a newly registered member. 
# The easiest way is to create a class with the data we want to send to AlphaMail.
# AlphaMail will then run your template along with the received object (myMember).
 
# The class for the new member, could also be a customer, order, cart, forgotten password etc.
class NewMember
	attr_accessor :name
	attr_accessor :password
	
	def initialize(name = 'Unknown', password = 'unset1')
		@name = name
		@password = password
	end
	
	def to_json(*a)
		{
			'name'		=>	name,
			'password'	=>	password
			
		}.to_json(*a)
	end
end

# Demo 1 --------------------------------------------------
# Lets send an email!
# ---------------------------------------------------------

# The email content (in this case, member info)
myMember = NewMember.new('Ruby Diamond Ruben', 'p4sSw0rd')

# The payload, our new member along with some other things
myPayload = AlphaMail::MessagePayload.new

# Set payload fields
myPayload.project_id = 139						# Project ID
myPayload.receiver_id = 1						# Receiver ID
myPayload.sender.name = 'Jack Sender'					# Sender name
myPayload.sender.email = 'jack@example.com'				# Sender email
myPayload.receiver.name = 'John Doe'					# Receiver name
myPayload.receiver.email = 'john.doe@example.com'			# Receiver email

# Set the body (our new member)
myPayload.body = myMember						# The content of out email, our new member

# Create and setup a new email service
# Replace YOUR-TOKEN-HERE with your own token. You can create tokens in Dashboard
myService = AlphaMail::EmailService.new 'http://api.amail.io/v1', 'YOUR-TOKEN-HERE'

# Now, the fun part, sending it!
am_res = myService.queue(myPayload)

# Your result will be stored in an AlphaMail::Result object
puts "#{am_res.error_code} #{am_res.message}"


# Demo 2 --------------------------------------------------
# Shorthand: All the code above can be written in a shorter way.
# ---------------------------------------------------------
service_url = 'http://api.amail.io/v1'
myToken = 'YOUR-TOKEN-HERE'
am_res = AlphaMail::EmailService.new(service_url, myToken).queue(AlphaMail::MessagePayload.new(
	139,								# Project ID
	2,								# Receiver ID
	AlphaMail::Contact.new('Jack Sender', 'jack@example.com'),	# Sender
	AlphaMail::Contact.new('John Doe', 'john.doe@example.com'),	# Receiver
	NewMember.new('Ruby Diamond Ruben', 'p4sSw0rd')			# Body object
))
# Print
puts "#{am_res.error_code} #{am_res.message}"


